==> org.eclipse.gef4.mvc.examples.logo.source_0.1.0.201506081138.jar: org/eclipse/gef4/mvc/examples/logo/parts/FXDeleteHoverHandlePart.java <==
/*******************************************************************************
 * Copyright (c) 2014, 2015 itemis AG and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Matthias Wienand (itemis AG) - initial API and implementation
 *
 *******************************************************************************/
package org.eclipse.gef4.mvc.examples.logo.parts;

import java.net.URL;

import javafx.scene.image.Image;

import org.eclipse.gef4.fx.nodes.FXImageViewHoverOverlay;

public class FXDeleteHoverHandlePart extends
		AbstractLogoHoverHandlePart<FXImageViewHoverOverlay> {

	public static final String IMG_DELETE = "/delete_obj.gif";
	public static final String IMG_DELETE_DISABLED = "/delete_obj_disabled.gif";

	@Override
	protected FXImageViewHoverOverlay createVisual() {
		URL overlayImageResource = FXDeleteHoverHandlePart.class
				.getResource(IMG_DELETE);
		if (overlayImageResource == null) {
			throw new IllegalStateException("Cannot find resource <"
					+ IMG_DELETE + ">.");
		}
		Image overlayImage = new Image(overlayImageResource.toExternalForm());

		URL baseImageResource = FXDeleteHoverHandlePart.class
				.getResource(IMG_DELETE_DISABLED);
		if (baseImageResource == null) {
			throw new IllegalStateException("Cannot find resource <"
					+ IMG_DELETE_DISABLED + ">.");
		}
		Image baseImage = new Image(baseImageResource.toExternalForm());

		FXImageViewHoverOverlay blendImageView = new FXImageViewHoverOverlay();
		blendImageView.baseImageProperty().set(baseImage);
		blendImageView.overlayImageProperty().set(overlayImage);
		return blendImageView;
	}

}

==> org.eclipse.gef4.mvc.examples.logo.source_0.2.0.201509140217.jar: org/eclipse/gef4/mvc/examples/logo/parts/FXDeleteHoverHandlePart.java <==
/*******************************************************************************
 * Copyright (c) 2014, 2015 itemis AG and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Matthias Wienand (itemis AG) - initial API and implementation
 *
 *******************************************************************************/
package org.eclipse.gef4.mvc.examples.logo.parts;

import java.net.URL;

import javafx.scene.image.Image;

import org.eclipse.gef4.fx.nodes.FXImageViewHoverOverlay;

public class FXDeleteHoverHandlePart
		extends AbstractLogoHoverHandlePart<FXImageViewHoverOverlay> {

	public static final String IMG_DELETE = "/delete_obj.gif";
	public static final String IMG_DELETE_DISABLED = "/delete_obj_disabled.gif";

	@Override
	protected FXImageViewHoverOverlay createVisual() {
		URL overlayImageResource = FXDeleteHoverHandlePart.class
				.getResource(IMG_DELETE);
		if (overlayImageResource == null) {
			throw new IllegalStateException(
					"Cannot find resource <" + IMG_DELETE + ">.");
		}
		Image overlayImage = new Image(overlayImageResource.toExternalForm());

		URL baseImageResource = FXDeleteHoverHandlePart.class
				.getResource(IMG_DELETE_DISABLED);
		if (baseImageResource == null) {
			throw new IllegalStateException(
					"Cannot find resource <" + IMG_DELETE_DISABLED + ">.");
		}
		Image baseImage = new Image(baseImageResource.toExternalForm());

		FXImageViewHoverOverlay blendImageView = new FXImageViewHoverOverlay();
		blendImageView.baseImageProperty().set(baseImage);
		blendImageView.overlayImageProperty().set(overlayImage);
		return blendImageView;
	}

}
